@@ -21,16 +21,13 @@
 #include <Akonadi/Calendar/ITIPHandler>
 
 // Class to edit counter proposals through incidence editors
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 class INCIDENCEEDITOR_EXPORT GroupwareUiDelegate : public Akonadi::GroupwareUiDelegate
 {
 public:
 
-    void requestIncidenceEditor(const Akonadi::Item &item) Q_DECL_OVERRIDE;
-    void setCalendar(const Akonadi::ETMCalendar::Ptr &calendar) Q_DECL_OVERRIDE;
-    void createCalendar() Q_DECL_OVERRIDE;
+    void requestIncidenceEditor(const Akonadi::Item &item) override;
+    void setCalendar(const Akonadi::ETMCalendar::Ptr &calendar) override;
+    void createCalendar() override;
 };
-
 }
