@@ -23,14 +23,11 @@
 
 #include "incidenceeditor-ng.h"
 
-namespace Ui
-{
+namespace Ui {
 class EventOrTodoDesktop;
 }
 
-namespace IncidenceEditorNG
-{
-
+namespace IncidenceEditorNG {
 class IncidenceDescriptionPrivate;
 
 /**
@@ -48,14 +45,14 @@ public:
 
     ~IncidenceDescription();
 
-    void load(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    void save(const KCalCore::Incidence::Ptr &incidence) Q_DECL_OVERRIDE;
-    bool isDirty() const Q_DECL_OVERRIDE;
+    void load(const KCalCore::Incidence::Ptr &incidence) override;
+    void save(const KCalCore::Incidence::Ptr &incidence) override;
+    bool isDirty() const override;
 
     // For debugging pursposes
     bool richTextEnabled() const;
 
-    void printDebugInfo() const Q_DECL_OVERRIDE;
+    void printDebugInfo() const override;
 
 private:
     void toggleRichTextDescription();
@@ -69,7 +66,6 @@ private:
     IncidenceDescriptionPrivate *const d;
     //@endcond
 };
-
 }
 
 #endif
