@@ -19,13 +19,13 @@
  *
  */
 #include "resourceitem.h"
-#include "helper_p.h"
 
 #include <kldap/ldapserver.h>
 
 using namespace IncidenceEditorNG;
 
-ResourceItem::ResourceItem(const KLDAP::LdapDN &dn, const QStringList &attrs, const KLDAP::LdapClient &ldapClient, const ResourceItem::Ptr &parent)
+ResourceItem::ResourceItem(const KLDAP::LdapDN &dn, const QStringList &attrs,
+                           const KLDAP::LdapClient &ldapClient, const ResourceItem::Ptr &parent)
     : parentItem(parent)
     , dn(dn)
     , mAttrs(attrs)
@@ -151,7 +151,7 @@ const KLDAP::LdapClient &ResourceItem::ldapClient() const
     return mLdapClient;
 }
 
-void ResourceItem::slotLDAPResult(const KLDAP::LdapClient &/*client*/,
+void ResourceItem::slotLDAPResult(const KLDAP::LdapClient & /*client*/,
                                   const KLDAP::LdapObject &obj)
 {
     mLdapObject = obj;
